![PyPI - Version](https://img.shields.io/pypi/v/textual-timepiece)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/textual-timepiece?link=https%3A%2F%2Fpypi.org%2Fproject%2Ftextual-timepiece%2F)
![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/ddkasa/textual-timepiece/ci.yaml?link=https%3A%2F%2Fgithub.com%2Fddkasa%2Ftextual-timepiece%2Factions%2Fworkflows%2Fci.yaml)

# Textual Timepiece

> Various time management related widgets for the [Textual](https://github.com/Textualize/textual) framework.

## Demo

Try the widgets out beforehand with `uv`:

```sh
uvx --from git+https://github.com/ddkasa/textual-timepiece demo
```

## Install

```sh
pip install textual-timepiece
```

```sh
uv add textual-timepiece
```

```sh
poetry add textual-timepiece
```

> [!NOTE]
> Requires [whenever](https://github.com/ariebovenberg/whenever) as an additional dependency.

## Included Widgets

- `DatePicker`
- `DurationPicker`
- `TimePicker`
- `DateTimePicker`
- `DateRangePicker`
- `DateTimeRangePicker`
- `ActivityHeatmap`
- `HeatmapManager`
- _And more to come..._

## License

MIT. Check [LICENSE](LICENSE.md) for more information.
